@@ -7,12 +7,12 @@
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
- 
+
  DUMMY is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
-    
+
  You should have received a copy of the GNU General Public License
  along with DUMMY.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -20,7 +20,4 @@
 #ifndef _GAME_H_
 #define _GAME_H_
 
-
-
-
-#endif
+#include "weaver/weaver.h"
