@@ -7,12 +7,12 @@
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
- 
+
  Weaver API is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
-    
+
  You should have received a copy of the GNU General Public License
  along with Weaver API.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -22,10 +22,6 @@
 
 #define destroy_vector3(x) free(x)
 
-#define move_circle(circ, a, b)                 \
-  circ -> x += a;                               \
-  circ -> y += b; 
-
 struct vector3{
   float x, y, z;
   struct vector3 *previous, *top, *next;
@@ -33,5 +29,6 @@ struct vector3{
 
 struct vector3 *new_vector3(float, float, float);
 void rotate_circle(struct vector3 *, float, float, float);
+void move_circle(struct vector3 *, float, float);
 
 #endif
